summaryrefslogtreecommitdiffstats
path: root/lib/kformula
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:10:32 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:10:32 -0600
commit3fe437def8063926892bddf2dcc733861308836d (patch)
tree021d66ad023a32bc8ea0074a1ab3d01316aff8b0 /lib/kformula
parent5b8ab149469c8e186ee8b05d90c0103ae722dd85 (diff)
downloadkoffice-3fe437def8063926892bddf2dcc733861308836d.tar.gz
koffice-3fe437def8063926892bddf2dcc733861308836d.zip
Rename KCModule, KConfig, KIO, KServer, and KSocket to avoid conflicts with KDE4
Diffstat (limited to 'lib/kformula')
-rw-r--r--lib/kformula/contextstyle.cc2
-rw-r--r--lib/kformula/contextstyle.h2
-rw-r--r--lib/kformula/fontstyle.cc12
-rw-r--r--lib/kformula/kformulaconfigpage.cc4
-rw-r--r--lib/kformula/kformulaconfigpage.h10
-rw-r--r--lib/kformula/kformuladocument.cc2
-rw-r--r--lib/kformula/kformuladocument.h6
-rw-r--r--lib/kformula/symboltable.h2
8 files changed, 20 insertions, 20 deletions
diff --git a/lib/kformula/contextstyle.cc b/lib/kformula/contextstyle.cc
index b6067e10..a744e02d 100644
--- a/lib/kformula/contextstyle.cc
+++ b/lib/kformula/contextstyle.cc
@@ -89,7 +89,7 @@ const SymbolTable& ContextStyle::symbolTable() const
}
-void ContextStyle::readConfig( KConfig* config, bool init )
+void ContextStyle::readConfig( TDEConfig* config, bool init )
{
config->setGroup( "kformula Font" );
TQString fontName = config->readEntry( "defaultFont", "Times,12,-1,5,50,1,0,0,0,0" );
diff --git a/lib/kformula/contextstyle.h b/lib/kformula/contextstyle.h
index 11a103dd..edf9cefa 100644
--- a/lib/kformula/contextstyle.h
+++ b/lib/kformula/contextstyle.h
@@ -93,7 +93,7 @@ public:
* installation. Mark as false when this is not intended (i. e. creating
* configuration dialog from another component)
*/
- void readConfig( KConfig* config, bool init = true );
+ void readConfig( TDEConfig* config, bool init = true );
bool edit() const { return m_edit; }
void setEdit( bool e ) { m_edit = e; }
diff --git a/lib/kformula/fontstyle.cc b/lib/kformula/fontstyle.cc
index 0df68fcb..94f3c241 100644
--- a/lib/kformula/fontstyle.cc
+++ b/lib/kformula/fontstyle.cc
@@ -118,21 +118,21 @@ void FontStyle::installFonts()
for (TQStringList::iterator it = missing.begin(); it != missing.end(); ++it)
{
if ( *it == "arev sans" ) {
- if (!KIO::NetAccess::exists("fonts:/Personal/Arev.ttf", true, NULL))
+ if (!TDEIO::NetAccess::exists("fonts:/Personal/Arev.ttf", true, NULL))
urlList.append(locate("data", "kformula/fonts/Arev.ttf"));
- if (!KIO::NetAccess::exists("fonts:/Personal/ArevIt.ttf", true, NULL))
+ if (!TDEIO::NetAccess::exists("fonts:/Personal/ArevIt.ttf", true, NULL))
urlList.append(locate("data", "kformula/fonts/ArevIt.ttf"));
- if (!KIO::NetAccess::exists("fonts:/Personal/ArevBd.ttf", true, NULL))
+ if (!TDEIO::NetAccess::exists("fonts:/Personal/ArevBd.ttf", true, NULL))
urlList.append(locate("data", "kformula/fonts/ArevBd.ttf"));
- if (!KIO::NetAccess::exists("fonts:/Personal/ArevBI.ttf", true, NULL))
+ if (!TDEIO::NetAccess::exists("fonts:/Personal/ArevBI.ttf", true, NULL))
urlList.append(locate("data", "kformula/fonts/ArevBI.ttf"));
}
else {
- if (!KIO::NetAccess::exists("fonts:/Personal/" + *it + ".ttf", true, NULL))
+ if (!TDEIO::NetAccess::exists("fonts:/Personal/" + *it + ".ttf", true, NULL))
urlList.append(locate("data", "kformula/fonts/" + *it + ".ttf"));
}
}
- KIO::copy(urlList, "fonts:/Personal/", false);
+ TDEIO::copy(urlList, "fonts:/Personal/", false);
KMessageBox::information(tqApp->mainWidget(),
i18n("Some fonts have been installed to assure that symbols in formulas are properly visualized. You must restart the application in order so that changes take effect"));
}
diff --git a/lib/kformula/kformulaconfigpage.h b/lib/kformula/kformulaconfigpage.h
index 54856a04..37776f0f 100644
--- a/lib/kformula/kformulaconfigpage.h
+++ b/lib/kformula/kformulaconfigpage.h
@@ -39,7 +39,7 @@ class TQStringList;
class TQWidget;
class KColorButton;
-class KConfig;
+class TDEConfig;
class KListView;
class KPushButton;
class KIntNumInput;
@@ -55,7 +55,7 @@ class KOFORMULA_EXPORT ConfigurePage : public TQObject
public:
- ConfigurePage( Document* document, TQWidget* view, KConfig* config, TQVBox* box, char* name = 0 );
+ ConfigurePage( Document* document, TQWidget* view, TDEConfig* config, TQVBox* box, char* name = 0 );
void apply();
void slotDefault();
@@ -83,7 +83,7 @@ private:
Document* m_document;
TQWidget* m_view;
- KConfig* m_config;
+ TDEConfig* m_config;
TQFont defaultFont;
TQFont nameFont;
@@ -114,7 +114,7 @@ private:
//
// public:
-// MathFontsConfigurePage( Document* document, TQWidget* view, KConfig* config, TQVBox* box, char* name = 0 );
+// MathFontsConfigurePage( Document* document, TQWidget* view, TDEConfig* config, TQVBox* box, char* name = 0 );
// void apply();
// void slotDefault();
@@ -133,7 +133,7 @@ private:
// Document* m_document;
// TQWidget* m_view;
-// KConfig* m_config;
+// TDEConfig* m_config;
// KListView* availableFonts;
// KListView* requestedFonts;
diff --git a/lib/kformula/kformuladocument.cc b/lib/kformula/kformuladocument.cc
index 917d54c5..36b691de 100644
--- a/lib/kformula/kformuladocument.cc
+++ b/lib/kformula/kformuladocument.cc
@@ -368,7 +368,7 @@ void Document::introduceWrapper( DocumentWrapper* wrapper, bool init )
//////////////////////////////////////////////////////////////////////////////
-DocumentWrapper::DocumentWrapper( KConfig* config,
+DocumentWrapper::DocumentWrapper( TDEConfig* config,
KActionCollection* collection,
KoCommandHistory* history )
: m_document( 0 ),
diff --git a/lib/kformula/kformuladocument.h b/lib/kformula/kformuladocument.h
index 61fdb7cc..3cee9f0c 100644
--- a/lib/kformula/kformuladocument.h
+++ b/lib/kformula/kformuladocument.h
@@ -295,12 +295,12 @@ class KOFORMULA_EXPORT DocumentWrapper : public TQObject {
public:
- DocumentWrapper( KConfig* config,
+ DocumentWrapper( TDEConfig* config,
KActionCollection* collection,
KoCommandHistory* history = 0 );
~DocumentWrapper();
- KConfig* config() { return m_config; }
+ TDEConfig* config() { return m_config; }
KoCommandHistory* history() { return m_history; }
/**
@@ -495,7 +495,7 @@ private:
SymbolType m_rightBracketChar;
TQString m_selectedName;
- KConfig* m_config;
+ TDEConfig* m_config;
KoCommandHistory* m_history;
/**
diff --git a/lib/kformula/symboltable.h b/lib/kformula/symboltable.h
index 7820af81..99cebe46 100644
--- a/lib/kformula/symboltable.h
+++ b/lib/kformula/symboltable.h
@@ -30,7 +30,7 @@
#include "kformuladefs.h"
-class KConfig;
+class TDEConfig;
KFORMULA_NAMESPACE_BEGIN
diff --git a/lib/kformula/kformulaconfigpage.cc b/lib/kformula/kformulaconfigpage.cc
index 87160a98..a803dbc2 100644
--- a/lib/kformula/kformulaconfigpage.cc
+++ b/lib/kformula/kformulaconfigpage.cc
@@ -53,7 +53,7 @@
KFORMULA_NAMESPACE_BEGIN
-ConfigurePage::ConfigurePage( Document* document, TQWidget* view, KConfig* config, TQVBox* box, char* name )
+ConfigurePage::ConfigurePage( Document* document, TQWidget* view, TDEConfig* config, TQVBox* box, char* name )
: TQObject( box->parent(), name ), m_document( document ), m_view( view ), m_config( config ), m_changed( false )
{
const ContextStyle& contextStyle = document->getContextStyle( true );
@@ -342,7 +342,7 @@ void ConfigurePage::slotChanged()
// }
// MathFontsConfigurePage::MathFontsConfigurePage( Document* document, TQWidget* view,
// KConfig* config, TQVBox* box, char* name )
// : TQObject( box->parent(), name ), m_document( document ), m_view( view ), m_config( config )
// {
// TQWidget* fontWidget = new TQWidget( box );
@@ -342,7 +342,7 @@ void ConfigurePage::slotChanged()
// }
// MathFontsConfigurePage::MathFontsConfigurePage( Document* document, TQWidget* view,
-// KConfig* config, TQVBox* box, char* name )
+// TDEConfig* config, TQVBox* box, char* name )
// : TQObject( box->parent(), name ), m_document( document ), m_view( view ), m_config( config )
// {